<?php

/*** SEO Design Solutions theme functions ***/

if ($_GET['css'] == 'admin') {
	header('Content-type: text/css');
	sdstheme_admin_css();
	die();
}

sdstheme_filters();

$sdstheme_name = 'Small Business SEO';
$sdstheme_textdomain = 'sds';
$sdstheme_submitted_field = 'sdstheme_submitted';

function sdstheme_init() {

	/* Sidebar ads */

	if (get_option('sdstheme_sidebar_ads') === false) {

		$defaultSidebarAds = array();
		for ($i=1; $i<=4; $i++) {
			$defaultSidebarAds[$i]['image'] = '';
			$defaultSidebarAds[$i]['url'] = '';
			$defaultSidebarAds[$i]['title'] = "Sample Ad $i";
		}
		update_option('sdstheme_sidebar_ads', serialize($defaultSidebarAds));
	}

	if (get_option('sdstheme_sidebar_ad_count') === false) {
		update_option('sdstheme_sidebar_ad_count', 4);
	}

}
add_action('init', 'sdstheme_init');

function sdstheme_title() {
	if ( is_front_page() ){
		if ($title = get_option('sdstheme_frontpage_title'))
			echo htmlentities($title);
		else
			echo htmlentities(get_bloginfo('name').' - '.get_bloginfo('description'));
	} else {
		wp_title( '-', true, 'right' );
		echo wp_specialchars( get_bloginfo('name'), 1 );
	}
}

function sdstheme_meta() {
	if (is_front_page()) {
		if ($mds = get_option('sdstheme_frontpage_meta_description')) $md = $mds;
			else $md = get_bloginfo('description', true);

		$md = htmlentities($md);
		echo "\t<meta name=\"description\" content=\"$md\" />\n";

		if ($mks = get_option('sdstheme_frontpage_meta_keywords')) {
			$mk = htmlentities($mks);
			echo "\t<meta name=\"keywords\" content=\"$mk\" />\n";
		}
	}
}

function sdstheme_header_ad() {
	$headerAd = sdstheme_pick_ads("header", 1);
	sdstheme_output_ad($headerAd[0]);
}

function sdstheme_sidebar_ads() {
	$sidebarAds = sdstheme_pick_ads("sidebar", (int)get_option('sdstheme_sidebar_ad_count'));
	echo '<ul>';
	foreach($sidebarAds as $ad) sdstheme_output_ad($ad, '<li>', '</li>');
	echo '</ul><div class="clear"></div>';
}

function sdstheme_output_ad($data, $before='', $after='') {
	if (is_array($data)) {
		$image = htmlentities($data['image'], ENT_QUOTES);
		$url   = htmlentities($data['url'], ENT_QUOTES);
		$title = htmlentities($data['title'], ENT_QUOTES);

		if (!$image) $image = get_bloginfo('template_directory')."/images/ad-placeholder-125x125.jpg";

		$format = '<img src="%2$s" alt="%3$s" title="%3$s" />';
		if ($url) $format = '<a href="%1$s" rel="nofollow">'.$format.'</a>';

		printf($before.$format.$after, $url, $image, $title);
	}
}

function sdstheme_filters() {
	$options = array(	'sdstheme_nofollow_archive_links'	=> array('get_archives_link'),
				'sdstheme_nofollow_meta_links' 		=> array('register', 'loginout'),
				'sdstheme_nofollow_blogroll_links'	=> array('get_bookmarks'));

	foreach ($options as $option => $filters) {
		if (get_option($option) === 'true') {
			foreach ($filters as $filter)
				add_filter($filter, $option);
		}
	}
}

function sdstheme_add_nofollow($html) {

	if (strpos($html, 'nofollow') === false)
		return str_replace('<a href=', '<a rel="nofollow" href=', $html);
	else
		return $html;
}

function sdstheme_nofollow_archive_links($html) {
	return sdstheme_add_nofollow($html);
}

function sdstheme_nofollow_meta_links($html) {
	return sdstheme_add_nofollow($html);
}

function sdstheme_nofollow_blogroll_links($b) {

	for ($i=0; $i < count($b); $i++) {
		if (strpos($b[$i]->link_rel, "nofollow") === false)
			$b[$i]->link_rel .= " nofollow";
	}
	return $b;
}

function sdstheme_add_settings_pages() {

	global $sdstheme_name;

	$seo = add_theme_page(__("$sdstheme_name Theme - SEO Settings", $sdstheme_textdomain),
		__('SEO Settings', $sdstheme_textdomain), 'edit_themes', 'seosettings', 'sdstheme_seo_settings_page');

	$ads = add_theme_page(__("$sdstheme_name Theme - Advertising Settings", $sdstheme_textdomain),
		__('Ad Settings', $sdstheme_textdomain), 'edit_themes', 'adsettings', 'sdstheme_ad_settings_page');

	add_action( "admin_print_scripts-$seo", "sdstheme_admin_css_link" );
	add_action( "admin_print_scripts-$ads", "sdstheme_admin_css_link" );
}
add_action('admin_menu', 'sdstheme_add_settings_pages');


function sdstheme_admin_css_link() {
	$url = trailingslashit(get_bloginfo('template_url')).basename(__FILE__).'?css=admin';
	echo "<link rel='stylesheet' href='$url' type='text/css' />";
}

function sdstheme_str_starts_with($string, $start) {
	return ( strcmp( substr($string, 0, strlen($start)), $start ) === 0 );
}

function sdstheme_pick_ads($section, $count) {

	$allAds = sdstheme_get_ads($section);

	if (!is_array($allAds) || count($allAds) <= 0) {
		return array();

	} elseif (count($allAds) === 1) {
		return array_values($allAds);

	} else {

		if ($count > count($allAds)) $count = count($allAds);

		$returnedKeys = array_rand($allAds, $count);

		if (is_array($returnedKeys)) {
			$keys = $returnedKeys;
		} else {
			$keys = array();
			$keys[0] = $returnedKeys;
		}

		$adData = array();
		$i=0;
		foreach ($keys as $key) {
			$adData[$i] = $allAds[$key];
			$i++;
		}

		return $adData;
	}
}

function sdstheme_get_ads($section) {
	return maybe_unserialize(get_option("sdstheme_{$section}_ads"));
}

function sdstheme_have_ads($section) {
	return (count(sdstheme_get_ads($section)) > 0);
}

function sdstheme_should_update_settings() {

	global $sdstheme_textdomain, $sdstheme_submitted_field;

	if ( !current_user_can('edit_themes') )
		wp_die(__("Insufficient user privileges.", $sdstheme_textdomain));

	if ($_POST[$sdstheme_submitted_field] == 'Y') {
		check_admin_referer('sds-theme-update-settings');
		unset($_POST[$sdstheme_submitted_field]);
		return true;
	}

	return false;
}

function sdstheme_settings_textbox($id, $size=null, $value=null) {

	if (is_null($value)) {
		if ($value = get_option($id)) $value = htmlentities($value, ENT_QUOTES);
			else $value='';
	}

	if (is_null($size)) $sizeAttr=''; else $sizeAttr = " size='$size'";
	echo "<input type='text' name='$id' id='$id' value='$value'$sizeAttr />";
}

function sdstheme_settings_textarea($id, $cols, $rows) {
	if ($value = get_option($id)) $value = htmlentities($value); else $value='';
	echo "<textarea name='$id' id='$id' cols='$cols' rows='$rows'>$value</textarea>";
}

function sdstheme_settings_checkbox($id) {
	$value = get_option($id);
	if ('true' == $value) $checked="checked='checked' "; else $checked="";
	echo "<input type='checkbox' name='$id' id='$id' value='true' $checked/>";
}

function sdstheme_handle_checkbox($id) {
	if (!isset($_POST[$id])) update_option($id, "false");
}

function sdstheme_seo_settings_page() {

	global $sdstheme_name, $sdstheme_textdomain, $sdstheme_submitted_field;

	if (sdstheme_should_update_settings()) {

		sdstheme_handle_checkbox('sdstheme_nofollow_archive_links');
		sdstheme_handle_checkbox('sdstheme_nofollow_meta_links');
		sdstheme_handle_checkbox('sdstheme_nofollow_blogroll_links');

		foreach ($_POST as $field => $value) {
			if (sdstheme_str_starts_with($field, "sdstheme_")) {
				update_option($field, stripslashes($value));
			}
		}

		echo '<div id="message" class="updated fade"><p><strong>' . __('Settings saved.', $sdstheme_textdomain) . '</strong></p></div>';
	}
	?>
	<div id="sdstheme_settings_page" class="wrap">
	<h2><?php _e("$sdstheme_name Theme - SEO Settings", $sdstheme_textdomain); ?></h2>
	<form name="sdstheme_seo_settings" id="sdstheme_seo_settings" method="post" action="">
		<input type="hidden" name="<?php echo $sdstheme_submitted_field; ?>" value="Y" />
		<table class="form-table">
		<tr valign="top">
			<th scope="row"><label for="sdstheme_frontpage_title"><?php _e("Frontpage Title", $sdstheme_textdomain) ?></label></th>
			<td>
				<div><?php sdstheme_settings_textbox('sdstheme_frontpage_title', 40) ?></div>
				<p><?php _e("The text you enter as the title will appear in the title bars of visitors' browsers, ".
						"as well as in search result listings for your frontpage.", $sdstheme_textdomain) ?></p>
			</td>
		</tr>
		<tr valign="top">
			<th scope="row"><label for="sdstheme_frontpage_meta_description"><?php _e("Frontpage Meta Description", $sdstheme_textdomain) ?></label></th>
			<td>
				<div><?php sdstheme_settings_textarea('sdstheme_frontpage_meta_description', 60, 2) ?></div>
				<p><?php _e("The text you enter here will be served as a suggestion to the search engines ".
						"as to what text should appear under the title when your front page shows up in search results. ".
						"If you don't specify a meta description here, your blog's tagline will be used.",
						$sdstheme_textdomain) ?></p>
			</td>
		</tr>
		<tr valign="top">
			<th scope="row"><label for="sdstheme_frontpage_meta_keywords"><?php _e("Frontpage Meta Keywords", $sdstheme_textdomain) ?></label></th>
			<td>
				<div><?php sdstheme_settings_textarea('sdstheme_frontpage_meta_keywords', 60, 2) ?></div>
				<p><?php _e("Indicate to the search engines which keywords are applicable to your blog by entering them here. ".
						"Separate the keywords with commas.", $sdstheme_textdomain) ?></p>
			</td>
		</tr>
		<tr valign="top">
			<th scope="row"><?php _e("Nofollow", $sdstheme_textdomain) ?></th>
			<td>
				<div><fieldset><legend class="hidden"><?php _e("Nofollow", $sdstheme_textdomain) ?></legend>
					<label for="sdstheme_nofollow_meta_links">
						<?php sdstheme_settings_checkbox('sdstheme_nofollow_meta_links') ?>
						<?php _e("Register/login links", $sdstheme_textdomain) ?></label><br />
					<label for="sdstheme_nofollow_blogroll_links">
						<?php sdstheme_settings_checkbox('sdstheme_nofollow_blogroll_links') ?>
						<?php _e("Link entries (a.k.a. blogroll links)", $sdstheme_textdomain) ?></label><br />
					<label for="sdstheme_nofollow_archive_links">
						<?php sdstheme_settings_checkbox('sdstheme_nofollow_archive_links') ?>
						<?php _e("Links to date-based archives", $sdstheme_textdomain) ?></label>
				</fieldset></div>
				<p><?php _e("Using the checkboxes above, you can select the sets of links to which you want to add the nofollow attribute. The nofollow attribute tells Google (and some other search engines) to give less weight to the nofollow'd link, in favor of other links on the page.", $sdstheme_textdomain) ?></p>
			</td>
		</tr>
		</table>

		<p id="sdstheme_submit_button"><span class="submit">
			<input type="submit" name="submit" value="<?php _e('Update Settings', $sdstheme_textdomain) ?>" />
		</span></p>
		<?php wp_nonce_field('sds-theme-update-settings'); ?>
	</form>
	</div>
	<?php
}

function sdstheme_update_ad_data($section) {

	$data = array();

	for ($ad=1; $ad<=10; $ad++) {
		$image = $_POST["sdstheme_{$section}_ad{$ad}_image"];
		$url   = $_POST["sdstheme_{$section}_ad{$ad}_url"];
		$title = $_POST["sdstheme_{$section}_ad{$ad}_title"];

		if ($image || $url || $title) {
			$data[$ad]['image'] = $image;
			$data[$ad]['url']   = $url;
			$data[$ad]['title'] = $title;
		}
	}
	update_option("sdstheme_{$section}_ads", serialize($data));
}


function sdstheme_ad_settings_page() {

	global $sdstheme_name, $sdstheme_textdomain, $sdstheme_submitted_field;

	if (sdstheme_should_update_settings()) {

		sdstheme_update_ad_data("sidebar");

		update_option("sdstheme_sidebar_ad_count", $_POST['sdstheme_sidebar_ad_count']);

		echo '<div id="message" class="updated fade"><p><strong>' . __('Settings saved.', $sdstheme_textdomain) . '</strong></p></div>';
	}

	$headerAds = maybe_unserialize(get_option("sdstheme_header_ads"));
	$sidebarAds = maybe_unserialize(get_option("sdstheme_sidebar_ads"));
	?>
	<div id="sdstheme_settings_page" class="wrap">
	<h2><?php _e("$sdstheme_name Theme - Advertising Settings", $sdstheme_textdomain); ?></h2>
	<p><?php _e("This page allows you to easily add advertising to your blog. Once you're done changing the settings, ".
		"click the &quot;Update Settings&quot; button at the bottom of the page.", $sdstheme_textdomain); ?></p>
	<form name="sdstheme_ad_settings" id="sdstheme_ad_settings" method="post" action="">
		<input type="hidden" name="<?php echo $sdstheme_submitted_field; ?>" value="Y" />

		<h3><?php _e("Sidebar Ads (125x125 pixels)", $sdstheme_textdomain); ?></h3>
		<p><?php _e("In the table below, you can fill in data about advertising images that you want displayed in your sidebar. ".
				"Up to 10 sidebar ads are supported. ".
				"Remember to include <tt>http://</tt> in your URLs if necessary.", $sdstheme_textdomain); ?></p>
		<table class="form-table sdstheme_ad_data">
			<tr>
				<th scope="col">#</th>
				<th scope="col"><?php _e("Image URL", $sdstheme_textdomain); ?> <small><?php _e("(Images should be 125x125 pixels)", $sdstheme_textdomain); ?></small></th>
				<th scope="col"><?php _e("Clickthrough URL", $sdstheme_textdomain); ?> <small><?php _e("(Where a visitor is taken when the ad is clicked)", $sdstheme_textdomain); ?></small></th>
				<th scope="col"><?php _e("Hover Title", $sdstheme_textdomain); ?> <small><?php _e("(The text that appears when a visitor hovers his/her mouse over the ad image)", $sdstheme_textdomain); ?></small></th>
			</tr>
			<?php for ($ad=1; $ad<=10; $ad++) { ?><tr>
				<th scope="row" class="adnumber"><?php echo $ad; ?></th>
				<td><?php sdstheme_settings_textbox("sdstheme_sidebar_ad{$ad}_image", null, $sidebarAds[$ad]['image']) ?></td>
				<td><?php sdstheme_settings_textbox("sdstheme_sidebar_ad{$ad}_url",   null, $sidebarAds[$ad]['url']) ?></td>
				<td><?php sdstheme_settings_textbox("sdstheme_sidebar_ad{$ad}_title", null, $sidebarAds[$ad]['title']) ?></td>
			</tr><?php } ?>
		</table>
		<table class="form-table"><tr>
			<th scope="row">Number of ads to display on sidebar:</th>
			<td><select name="sdstheme_sidebar_ad_count" id="sdstheme_sidebar_ad_count"><?php
$adCount = get_option('sdstheme_sidebar_ad_count');
for ($i=0; $i<=10; $i++) {
	if ($adCount == $i) $selected = ' selected="selected"'; else $selected='';
	echo "<option$selected>$i</option>";
} ?></select></td>
			<td><p><?php _e("This determines how many ads are shown on your sidebar at a time. If you select zero, no ads will be shown. ".
					"If you select a number that's less than your total number of ads, ".
					"then the ads displayed on the sidebar will be chosen at random every time a page on your blog is loaded.",
					$sdstheme_textdomain); ?></p></td>
		</tr></table>

		<p id="sdstheme_submit_button"><span class="submit">
			<input type="submit" name="submit" value="<?php _e('Update Settings', $sdstheme_textdomain) ?>" />
		</span></p>
		<?php wp_nonce_field('sds-theme-update-settings'); ?>
	</form>
	</div>
	<?php
}

function sdstheme_admin_css() { ?>

/* General styles */

div#sdstheme_settings_page table.form-table fieldset {
	border-style: none;
}

div#sdstheme_settings_page p#sdstheme_submit_button {
	margin-top: 3em;
}

/* Ad settings styles */

form#sdstheme_ad_settings h3 {
	margin-top: 3em;
}

form#sdstheme_ad_settings table.form-table td, form#sdstheme_ad_settings table.form-table th {
	vertical-align: middle;
}

form#sdstheme_ad_settings table.sdstheme_ad_data th {
	font-weight: bold;
	text-align: center;
}

form#sdstheme_ad_settings table.sdstheme_ad_data th small {
	display: block;
	font-weight: normal;
}

form#sdstheme_ad_settings table.sdstheme_ad_data th.adnumber {
	width: 4%;
}

form#sdstheme_ad_settings table.sdstheme_ad_data td {
	width: 32%;
	text-align: center;
}

form#sdstheme_ad_settings table.sdstheme_ad_data td input {
	width: 90%;
}

<?php }


function widget_sdstheme_ads($args) {
	if (sdstheme_have_ads('sidebar') && get_option('sdstheme_sidebar_ad_count') > 0) {
		extract($args);
		echo $before_widget;
		sdstheme_sidebar_ads();
		echo $after_widget;
	}
}

function widget_sdstheme_ads_control() {
	echo '<p>You can edit the advertisements shown in this widget by going to <a href="themes.php?page=adsettings">Appearance&nbsp;&#8658;&nbsp;Ad Settings</a>.</p>';
}

function sdstheme_widgets_init() {
	global $sdstheme_name, $sdstheme_textdomain;
	$widget_ops = array(
		'classname'    =>  'widget_ads',
		'description'  =>  __( "Sidebar advertisements, as specified in Appearance &#8658; Ad Settings ($sdstheme_name theme)", $sdstheme_textdomain )
	);
	wp_register_sidebar_widget( 'ads', __( 'Sidebar Ads', $sdstheme_textdomain ), 'widget_sdstheme_ads', $widget_ops );
	wp_register_widget_control( 'ads', __( 'Sidebar Ads', $sdstheme_textdomain ), 'widget_sdstheme_ads_control' );
}
add_action( 'init', 'sdstheme_widgets_init' );


load_theme_textdomain($sdstheme_textdomain);







/*
This file is part of SANDBOX.

SANDBOX is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 2 of the License, or (at your option) any later version.

SANDBOX is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with SANDBOX. If not, see http://www.gnu.org/licenses/.
*/

// Produces a list of pages in the header without whitespace
function sandbox_globalnav() {
	if ( $menu = str_replace( array( "\r", "\n", "\t" ), '', wp_list_pages('title_li=&sort_column=menu_order&echo=0') ) )
		$menu = '<ul>' . $menu . '</ul>';
	$menu = '<div class="menu">' . $menu . "</div>\n";
	echo apply_filters( 'globalnav_menu', $menu ); // Filter to override default globalnav: globalnav_menu
}

// Generates semantic classes for BODY element
function sandbox_body_class( $print = true ) {
	global $wp_query, $current_user;

	// It's surely a WordPress blog, right?
	$c = array('wordpress');

	// Applies the time- and date-based classes (below) to BODY element
	sandbox_date_classes( time(), $c );

	// Generic semantic classes for what type of content is displayed
	is_front_page()  ? $c[] = 'home'       : null; // For the front page, if set
	is_home()        ? $c[] = 'blog'       : null; // For the blog posts page, if set
	is_archive()     ? $c[] = 'archive'    : null;
	is_date()        ? $c[] = 'date'       : null;
	is_search()      ? $c[] = 'search'     : null;
	is_paged()       ? $c[] = 'paged'      : null;
	is_attachment()  ? $c[] = 'attachment' : null;
	is_404()         ? $c[] = 'four04'     : null; // CSS does not allow a digit as first character

	// Special classes for BODY element when a single post
	if ( is_single() ) {
		$postID = $wp_query->post->ID;
		the_post();

		// Adds 'single' class and class with the post ID
		$c[] = 'single postid-' . $postID;

		// Adds classes for the month, day, and hour when the post was published
		if ( isset( $wp_query->post->post_date ) )
			sandbox_date_classes( mysql2date( 'U', $wp_query->post->post_date ), $c, 's-' );

		// Adds category classes for each category on single posts
		if ( $cats = get_the_category() )
			foreach ( $cats as $cat )
				$c[] = 's-category-' . $cat->slug;

		// Adds tag classes for each tags on single posts
		if ( $tags = get_the_tags() )
			foreach ( $tags as $tag )
				$c[] = 's-tag-' . $tag->slug;

		// Adds MIME-specific classes for attachments
		if ( is_attachment() ) {
			$mime_type = get_post_mime_type();
			$mime_prefix = array( 'application/', 'image/', 'text/', 'audio/', 'video/', 'music/' );
				$c[] = 'attachmentid-' . $postID . ' attachment-' . str_replace( $mime_prefix, "", "$mime_type" );
		}

		// Adds author class for the post author
		$c[] = 's-author-' . sanitize_title_with_dashes(strtolower(get_the_author_login()));
		rewind_posts();
	}

	// Author name classes for BODY on author archives
	elseif ( is_author() ) {
		$author = $wp_query->get_queried_object();
		$c[] = 'author';
		$c[] = 'author-' . $author->user_nicename;
	}

	// Category name classes for BODY on category archvies
	elseif ( is_category() ) {
		$cat = $wp_query->get_queried_object();
		$c[] = 'category';
		$c[] = 'category-' . $cat->slug;
	}

	// Tag name classes for BODY on tag archives
	elseif ( is_tag() ) {
		$tags = $wp_query->get_queried_object();
		$c[] = 'tag';
		$c[] = 'tag-' . $tags->slug;
	}

	// Page author for BODY on 'pages'
	elseif ( is_page() ) {
		$pageID = $wp_query->post->ID;
		$page_children = wp_list_pages("child_of=$pageID&echo=0");
		the_post();
		$c[] = 'page pageid-' . $pageID;
		$c[] = 'page-author-' . sanitize_title_with_dashes(strtolower(get_the_author('login')));
		// Checks to see if the page has children and/or is a child page; props to Adam
		if ( $page_children )
			$c[] = 'page-parent';
		if ( $wp_query->post->post_parent )
			$c[] = 'page-child parent-pageid-' . $wp_query->post->post_parent;
		if ( is_page_template() ) // Hat tip to Ian, themeshaper.com
			$c[] = 'page-template page-template-' . str_replace( '.php', '-php', get_post_meta( $pageID, '_wp_page_template', true ) );
		rewind_posts();
	}

	// Search classes for results or no results
	elseif ( is_search() ) {
		the_post();
		if ( have_posts() ) {
			$c[] = 'search-results';
		} else {
			$c[] = 'search-no-results';
		}
		rewind_posts();
	}

	// For when a visitor is logged in while browsing
	if ( $current_user->ID )
		$c[] = 'loggedin';

	// Paged classes; for 'page X' classes of index, single, etc.
	if ( ( ( $page = $wp_query->get('paged') ) || ( $page = $wp_query->get('page') ) ) && $page > 1 ) {
		$c[] = 'paged-' . $page;
		if ( is_single() ) {
			$c[] = 'single-paged-' . $page;
		} elseif ( is_page() ) {
			$c[] = 'page-paged-' . $page;
		} elseif ( is_category() ) {
			$c[] = 'category-paged-' . $page;
		} elseif ( is_tag() ) {
			$c[] = 'tag-paged-' . $page;
		} elseif ( is_date() ) {
			$c[] = 'date-paged-' . $page;
		} elseif ( is_author() ) {
			$c[] = 'author-paged-' . $page;
		} elseif ( is_search() ) {
			$c[] = 'search-paged-' . $page;
		}
	}

	// Separates classes with a single space, collates classes for BODY
	$c = join( ' ', apply_filters( 'body_class',  $c ) ); // Available filter: body_class

	// And tada!
	return $print ? print($c) : $c;
}

// Generates semantic classes for each post DIV element
function sandbox_post_class( $print = true ) {
	global $post, $sandbox_post_alt;

	// hentry for hAtom compliace, gets 'alt' for every other post DIV, describes the post type and p[n]
	$c = array( 'hentry', "p$sandbox_post_alt", $post->post_type, $post->post_status );

	// Author for the post queried
	$c[] = 'author-' . sanitize_title_with_dashes(strtolower(get_the_author('login')));

	// Category for the post queried
	foreach ( (array) get_the_category() as $cat )
		$c[] = 'category-' . $cat->slug;

	// Tags for the post queried; if not tagged, use .untagged
	if ( get_the_tags() == null ) {
		$c[] = 'untagged';
	} else {
		foreach ( (array) get_the_tags() as $tag )
			$c[] = 'tag-' . $tag->slug;
	}

	// For password-protected posts
	if ( $post->post_password )
		$c[] = 'protected';

	// Applies the time- and date-based classes (below) to post DIV
	sandbox_date_classes( mysql2date( 'U', $post->post_date ), $c );

	// If it's the other to the every, then add 'alt' class
	if ( ++$sandbox_post_alt % 2 )
		$c[] = 'alt';

	// Separates classes with a single space, collates classes for post DIV
	$c = join( ' ', apply_filters( 'post_class', $c ) ); // Available filter: post_class

	// And tada!
	return $print ? print($c) : $c;
}

// Define the num val for 'alt' classes (in post DIV and comment LI)
$sandbox_post_alt = 1;

// Generates semantic classes for each comment LI element
function sandbox_comment_class( $print = true ) {
	global $comment, $post, $sandbox_comment_alt;

	// Collects the comment type (comment, trackback),
	$c = array( $comment->comment_type );

	// Counts trackbacks (t[n]) or comments (c[n])
	if ( $comment->comment_type == 'comment' ) {
		$c[] = "c$sandbox_comment_alt";
	} else {
		$c[] = "t$sandbox_comment_alt";
	}

	// If the comment author has an id (registered), then print the log in name
	if ( $comment->user_id > 0 ) {
		$user = get_userdata($comment->user_id);
		// For all registered users, 'byuser'; to specificy the registered user, 'commentauthor+[log in name]'
		$c[] = 'byuser comment-author-' . sanitize_title_with_dashes(strtolower( $user->user_login ));
		// For comment authors who are the author of the post
		if ( $comment->user_id === $post->post_author )
			$c[] = 'bypostauthor';
	}

	// If it's the other to the every, then add 'alt' class; collects time- and date-based classes
	sandbox_date_classes( mysql2date( 'U', $comment->comment_date ), $c, 'c-' );
	if ( ++$sandbox_comment_alt % 2 )
		$c[] = 'alt';

	// Separates classes with a single space, collates classes for comment LI
	$c = join( ' ', apply_filters( 'comment_class', $c ) ); // Available filter: comment_class

	// Tada again!
	return $print ? print($c) : $c;
}

// Generates time- and date-based classes for BODY, post DIVs, and comment LIs; relative to GMT (UTC)
function sandbox_date_classes( $t, &$c, $p = '' ) {
	$t = $t + ( get_option('gmt_offset') * 3600 );
	$c[] = $p . 'y' . gmdate( 'Y', $t ); // Year
	$c[] = $p . 'm' . gmdate( 'm', $t ); // Month
	$c[] = $p . 'd' . gmdate( 'd', $t ); // Day
	$c[] = $p . 'h' . gmdate( 'H', $t ); // Hour
}

// For category lists on category archives: Returns other categories except the current one (redundant)
function sandbox_cats_meow($glue) {
	$current_cat = single_cat_title( '', false );
	$separator = "\n";
	$cats = explode( $separator, get_the_category_list($separator) );
	foreach ( $cats as $i => $str ) {
		if ( strstr( $str, ">$current_cat<" ) ) {
			unset($cats[$i]);
			break;
		}
	}
	if ( empty($cats) )
		return false;

	return trim(join( $glue, $cats ));
}

// For tag lists on tag archives: Returns other tags except the current one (redundant)
function sandbox_tag_ur_it($glue) {
	$current_tag = single_tag_title( '', '',  false );
	$separator = "\n";
	$tags = explode( $separator, get_the_tag_list( "", "$separator", "" ) );
	foreach ( $tags as $i => $str ) {
		if ( strstr( $str, ">$current_tag<" ) ) {
			unset($tags[$i]);
			break;
		}
	}
	if ( empty($tags) )
		return false;

	return trim(join( $glue, $tags ));
}

// Produces an avatar image with the hCard-compliant photo class
function sandbox_commenter_link() {
	$commenter = get_comment_author_link();
	if ( ereg( '<a[^>]* class=[^>]+>', $commenter ) ) {
		$commenter = ereg_replace( '(<a[^>]* class=[\'"]?)', '\\1url ' , $commenter );
	} else {
		$commenter = ereg_replace( '(<a )/', '\\1class="url "' , $commenter );
	}
	$avatar_email = get_comment_author_email();
	$avatar_size = apply_filters( 'avatar_size', '32' ); // Available filter: avatar_size
	$avatar = str_replace( "class='avatar", "class='photo avatar", get_avatar( $avatar_email, $avatar_size ) );
	echo $avatar . ' <span class="fn n">' . $commenter . '</span>';
}

// Function to filter the default gallery shortcode
function sandbox_gallery($attr) {
	global $post;
	if ( isset($attr['orderby']) ) {
		$attr['orderby'] = sanitize_sql_orderby($attr['orderby']);
		if ( !$attr['orderby'] )
			unset($attr['orderby']);
	}

	extract(shortcode_atts( array(
		'orderby'    => 'menu_order ASC, ID ASC',
		'id'         => $post->ID,
		'itemtag'    => 'dl',
		'icontag'    => 'dt',
		'captiontag' => 'dd',
		'columns'    => 3,
		'size'       => 'thumbnail',
	), $attr ));

	$id           =  intval($id);
	$orderby      =  addslashes($orderby);
	$attachments  =  get_children("post_parent=$id&post_type=attachment&post_mime_type=image&orderby={$orderby}");

	if ( empty($attachments) )
		return null;

	if ( is_feed() ) {
		$output = "\n";
		foreach ( $attachments as $id => $attachment )
			$output .= wp_get_attachment_link( $id, $size, true ) . "\n";
		return $output;
	}

	$listtag     =  tag_escape($listtag);
	$itemtag     =  tag_escape($itemtag);
	$captiontag  =  tag_escape($captiontag);
	$columns     =  intval($columns);
	$itemwidth   =  $columns > 0 ? floor(100/$columns) : 100;

	$output = apply_filters( 'gallery_style', "\n" . '<div class="gallery">', 9 ); // Available filter: gallery_style

	foreach ( $attachments as $id => $attachment ) {
		$img_lnk = get_attachment_link($id);
		$img_src = wp_get_attachment_image_src( $id, $size );
		$img_src = $img_src[0];
		$img_alt = $attachment->post_excerpt;
		if ( $img_alt == null )
			$img_alt = $attachment->post_title;
		$img_rel = apply_filters( 'gallery_img_rel', 'attachment' ); // Available filter: gallery_img_rel
		$img_class = apply_filters( 'gallery_img_class', 'gallery-image' ); // Available filter: gallery_img_class

		$output  .=  "\n\t" . '<' . $itemtag . ' class="gallery-item gallery-columns-' . $columns .'">';
		$output  .=  "\n\t\t" . '<' . $icontag . ' class="gallery-icon"><a href="' . $img_lnk . '" title="' . $img_alt . '" rel="' . $img_rel . '"><img src="' . $img_src . '" alt="' . $img_alt . '" class="' . $img_class . ' attachment-' . $size . '" /></a></' . $icontag . '>';

		if ( $captiontag && trim($attachment->post_excerpt) ) {
			$output .= "\n\t\t" . '<' . $captiontag . ' class="gallery-caption">' . $attachment->post_excerpt . '</' . $captiontag . '>';
		}

		$output .= "\n\t" . '</' . $itemtag . '>';
		if ( $columns > 0 && ++$i % $columns == 0 )
			$output .= "\n</div>\n" . '<div class="gallery">';
	}
	$output .= "\n</div>\n";

	return $output;
}

// Widget: Search; to match the Sandbox style and replace Widget plugin default
function widget_sandbox_search($args) {
	extract($args);
	$options = get_option('widget_sandbox_search');
	$title = empty($options['title']) ? __( 'Search', 'sandbox' ) : attribute_escape($options['title']);
	$button = empty($options['button']) ? __( 'Go', 'sds' ) : attribute_escape($options['button']);
?>
			<?php echo $before_widget ?>
				<?php echo $before_title ?><label for="s"><?php echo $title ?></label><?php echo $after_title ?>
				<form id="searchform" class="blog-search" method="get" action="<?php bloginfo('home') ?>">
					<div>
						<input id="s" name="s" type="text" class="text" value="<?php the_search_query() ?>" size="20" tabindex="1" /><a href="#" onclick="javascript:document.getElementById('searchform').submit()" tabindex="2"><img src="<?php bloginfo('template_directory') ?>/images/search-submit-button.jpg" alt="<?php echo $button ?>" /></a>
					</div>
					<div class="clear"></div>
				</form>
			<?php echo $after_widget ?>
<?php
}

// Widget: Search; element controls for customizing text within Widget plugin
function widget_sandbox_search_control() {
	$options = $newoptions = get_option('widget_sandbox_search');
	if ( $_POST['search-submit'] ) {
		$newoptions['title'] = strip_tags(stripslashes( $_POST['search-title']));
		$newoptions['button'] = strip_tags(stripslashes( $_POST['search-button']));
	}
	if ( $options != $newoptions ) {
		$options = $newoptions;
		update_option( 'widget_sandbox_search', $options );
	}
	$title = attribute_escape($options['title']);
	$button = attribute_escape($options['button']);
?>
	<p><label for="search-title"><?php _e( 'Title:', 'sandbox' ) ?> <input class="widefat" id="search-title" name="search-title" type="text" value="<?php echo $title; ?>" /></label></p>
	<p><label for="search-button"><?php _e( 'Button Text:', 'sandbox' ) ?> <input class="widefat" id="search-button" name="search-button" type="text" value="<?php echo $button; ?>" /></label></p>
	<input type="hidden" id="search-submit" name="search-submit" value="1" />
<?php
}

// Widget: Meta; to match the Sandbox style and replace Widget plugin default
function widget_sandbox_meta($args) {
	extract($args);
	$options = get_option('widget_meta');
	$title = empty($options['title']) ? __( 'Meta', 'sandbox' ) : attribute_escape($options['title']);
?>
			<?php echo $before_widget; ?>
				<?php echo $before_title . $title . $after_title; ?>
				<ul>
					<?php wp_register() ?>

					<li><?php wp_loginout() ?></li>
					<?php wp_meta() ?>

				</ul>
			<?php echo $after_widget; ?>
<?php
}

// Widget: RSS links; to match the Sandbox style
function widget_sandbox_rsslinks($args) {
	extract($args);
	$options = get_option('widget_sandbox_rsslinks');
	$title = empty($options['title']) ? __( 'RSS Links', 'sandbox' ) : attribute_escape($options['title']);
?>
		<?php echo $before_widget; ?>
			<?php echo $before_title . $title . $after_title; ?>
			<ul>
				<li><a href="<?php bloginfo('rss2_url') ?>" title="<?php echo wp_specialchars( get_bloginfo('name'), 1 ) ?> <?php _e( 'Posts RSS feed', 'sandbox' ); ?>" rel="alternate" type="application/rss+xml"><?php _e( 'All posts', 'sandbox' ) ?></a></li>
				<li><a href="<?php bloginfo('comments_rss2_url') ?>" title="<?php echo wp_specialchars(bloginfo('name'), 1) ?> <?php _e( 'Comments RSS feed', 'sandbox' ); ?>" rel="alternate" type="application/rss+xml"><?php _e( 'All comments', 'sandbox' ) ?></a></li>
			</ul>
		<?php echo $after_widget; ?>
<?php
}

// Widget: RSS links; element controls for customizing text within Widget plugin
function widget_sandbox_rsslinks_control() {
	$options = $newoptions = get_option('widget_sandbox_rsslinks');
	if ( $_POST['rsslinks-submit'] ) {
		$newoptions['title'] = strip_tags( stripslashes( $_POST['rsslinks-title'] ) );
	}
	if ( $options != $newoptions ) {
		$options = $newoptions;
		update_option( 'widget_sandbox_rsslinks', $options );
	}
	$title = attribute_escape($options['title']);
?>
	<p><label for="rsslinks-title"><?php _e( 'Title:', 'sandbox' ) ?> <input class="widefat" id="rsslinks-title" name="rsslinks-title" type="text" value="<?php echo $title; ?>" /></label></p>
	<input type="hidden" id="rsslinks-submit" name="rsslinks-submit" value="1" />
<?php
}

// Widgets plugin: intializes the plugin after the widgets above have passed snuff
function sandbox_widgets_init() {
	if ( !function_exists('register_sidebars') )
		return;

	// Formats the Sandbox widgets, adding readability-improving whitespace
	$p = array(
		'before_widget'  =>   "\n\t\t\t" . '<li id="%1$s" class="widget %2$s">',
		'after_widget'   =>   "\n\t\t\t</li>\n",
		'before_title'   =>   "\n\t\t\t\t". '<div class="title widgettitle">',
		'after_title'    =>   "</div>\n"
	);

	// Table for how many? Two? This way, please.
	register_sidebars( 2, $p );

	// Finished intializing Widgets plugin, now let's load the Sandbox default widgets; first, Sandbox search widget
	$widget_ops = array(
		'classname'    =>  'widget_search',
		'description'  =>  __( "A search form for your blog (Sandbox)", "sandbox" )
	);
	wp_register_sidebar_widget( 'search', __( 'Search', 'sandbox' ), 'widget_sandbox_search', $widget_ops );
	unregister_widget_control('search'); // We're being Sandbox-specific; remove WP default
	wp_register_widget_control( 'search', __( 'Search', 'sandbox' ), 'widget_sandbox_search_control' );

	// Sandbox Meta widget
	$widget_ops = array(
		'classname'    =>  'widget_meta',
		'description'  =>  __( "Log in/out and administration links (Sandbox)", "sandbox" )
	);
	wp_register_sidebar_widget( 'meta', __( 'Meta', 'sandbox' ), 'widget_sandbox_meta', $widget_ops );
	unregister_widget_control('meta'); // We're being Sandbox-specific; remove WP default
	wp_register_widget_control( 'meta', __( 'Meta', 'sandbox' ), 'wp_widget_meta_control' );

	//Sandbox RSS Links widget
	$widget_ops = array(
		'classname'    =>  'widget_rss_links',
		'description'  =>  __( "RSS links for both posts and comments (Sandbox)", "sandbox" )
	);
	wp_register_sidebar_widget( 'rss_links', __( 'RSS Links', 'sandbox' ), 'widget_sandbox_rsslinks', $widget_ops );
	wp_register_widget_control( 'rss_links', __( 'RSS Links', 'sandbox' ), 'widget_sandbox_rsslinks_control' );
}

// Translate, if applicable
load_theme_textdomain('sandbox');

// Runs our code at the end to check that everything needed has loaded
add_action( 'init', 'sandbox_widgets_init' );

// Registers our function to filter default gallery shortcode
add_filter( 'post_gallery', 'sandbox_gallery', $attr );

// Adds filters for the description/meta content in archives.php
add_filter( 'archive_meta', 'wptexturize' );
add_filter( 'archive_meta', 'convert_smilies' );
add_filter( 'archive_meta', 'convert_chars' );
add_filter( 'archive_meta', 'wpautop' );

// Remember: the Sandbox is for play.
?>